@@ -95,10 +95,8 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
             return true;
         }
 
-        const QStringList parts = identifier.split(QLatin1Char(':'), QString::KeepEmptyParts);
-
-        // check whether it is cached, make sure second part present
-        if (parts.count() > 1 && CachedProvider::isCached(identifier)) {
+        // check whether it is cached already...
+        if (CachedProvider::isCached(identifier)) {
             QVariantList args;
             args << QLatin1String("String") << identifier;
 
@@ -110,6 +108,9 @@ bool ComicEngine::updateSourceEvent(const QString &identifier)
         }
 
         // ... start a new query otherwise
+        const QStringList parts = identifier.split(QLatin1Char(':'), QString::KeepEmptyParts);
+
+        //: are mandatory
         if (parts.count() < 2) {
             setData(identifier, QLatin1String("Error"), true);
             qWarning() << "Less than two arguments specified.";
@@ -252,7 +253,7 @@ void ComicEngine::error(ComicProvider *provider)
     QString identifier(provider->identifier());
     mIdentifierError = identifier;
 
-    qWarning() << identifier << "pluging reported an error.";
+    qWarning() << identifier << "plugging reported an error.";
 
     /**
      * Requests for the current day have no suffix (date or id)
