@@ -16,12 +16,12 @@ class DictionaryRunnerConfig : public KCModule
 	Q_OBJECT
 
 public:
-	DictionaryRunnerConfig(QWidget* parent = 0, const QVariantList& args = QVariantList());
+	explicit DictionaryRunnerConfig(QWidget* parent = nullptr, const QVariantList& args = QVariantList());
 
-public slots:
-	void save() Q_DECL_OVERRIDE;
-	void load() Q_DECL_OVERRIDE;
-	void defaults() Q_DECL_OVERRIDE;
+public Q_SLOTS:
+	void save() override;
+	void load() override;
+	void defaults() override;
 
 private:
 	QLineEdit *m_triggerWord;
